---
sidebar_position: 2
description: DePIN Board by Category
---

# DePIN Boards

The DePIN Boards provide an organized overview of various DePIN projects, categorized by their primary focus areas, such as compute, storage, wireless, energy, sensor, and mobility networks, among others.

The purpose of those boards is to provide educational and informational content only. This project is made on a best effort basis. If you have any feedback, please let us know by writing an [issue on our Gitea instance](https://git.ourworld.tf/tfgrid/info_docs_depin).

> To learn more about a specific project, click on the project name in the leftmost column.

## Compute Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements                                                                                               | Software Stack                                      | Open Source | Docker Support | ThreeFold Compatible | Notes                                                                                                                                                                                              |
|--------------------|--------------------------------|--------------------------------------------------------------------------------------------------------------------|----------------------------------------------------|-------------|----------------|---------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| [Render Network](./depin_specs/compute_networks/render_network.md) | Decentralized            | NVIDIA GPU, RAM, Strong Network Connectivity, SSDs                                                                  | CUDA                                               | Yes         | Yes            | Yes                       | GPU power sharing platform.                                                                                                          |
| [Akash Network](./depin_specs/compute_networks/akash_network.md)  | Fully Decentralized      | GPU, RAM, SSDs, Storage                                                                                             | Provider Software (Kubernetes Cluster Options)     | Yes         | Yes            | Yes                       | Purpose-built for public utility.                                                           |
| [Golem Network](./depin_specs/compute_networks/golem_network.md)  | Decentralized            | CPU, RAM, reliable OS, SSD, GPU                                                                                     | Ethereum, Docker                                   | Yes         | Yes            | Yes                       | Computing power sharing platform. |
| [iExec](./depin_specs/compute_networks/iexec.md)          | Decentralized            | VM with RAM, CPU                                                                                                    | Ethereum, Docker                                   | Yes         | Yes            | Yes                       | Decentralized cloud computing for dApps.                                                                                                                                                          |
| [Flux](./depin_specs/compute_networks/flux.md)           | Decentralized            | VM with RAM, GPU, HDD                                                                                               | Custom blockchain, Docker                          | Yes         | Yes            | Yes                       | For flexibility, scalability, and censorship resistance.                                         |
| [Internet Computer (Dfinity)](./depin_specs/compute_networks/internet_computer.md) | Decentralized            | CPU, RAM, NVMe SSD | Custom blockchain, Canisters                       | Yes         | No             | No                        | Build web apps and internet services.                                                            |
| [io.net](./depin_specs/compute_networks/io_net.md) | Decentralized        | NVIDIA/AMD GPUs, multi-core CPUs              | Ray, Kubernetes, PyTorch/TensorFlow            | Yes     | Yes        | No                | GPU/CPU aggregator for AI/ML workloads.             |




---

## Storage Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements                                                                                                                                                            | Software Stack               | Open Source | Docker Support | ThreeFold Compatible | Notes                                                                                                                 |
|--------------------|--------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------|-------------|----------------|---------------------------|------------------------------------------------------------------------------------------------------------------------|
| [Filecoin](./depin_specs/storage_networks/filecoin.md)       | Decentralized            | CPU, RAM, Nvidia GPU, VRAM, Intel SHA Extensions & Storage                                                                                                                       | Lotus Filecoin client        | Yes         | Yes            | Yes                       | Store and retrieve data over the internet.       |
| [Arweave](./depin_specs/storage_networks/arweave.md)        | Decentralized            | 4TB enterprise-grade hard drives with an average read speed of 200 MiB/s                                                                                                         | Arweave miner software       | Yes         | Yes            | Yes                       | Permanent and decentralized web inside an open ledger.           |
| [Storj](./depin_specs/storage_networks/storj.md)          | Decentralized            | Raspberry Pi, microSDXC Card, USB Cable, Storj cloud storage | Rclone, AWS CLI              | Yes         | Yes            | Yes                       | Enterprise-grade, globally distributed cloud object storage.                         |
| [Sia](./depin_specs/storage_networks/sia.md)            | Decentralized            | A quad-core CPU, RAM, SSD                                                                                                                                                        | Core software                | Yes         | Yes            | Yes                       | Data storage platform. |
| [Crust Network](./depin_specs/storage_networks/crust_network.md)  | Decentralized            | CPU, RAM, HDD, Network, SSD, Motherboard                                                                                                                                         | IPFS, Ubuntu                 | Yes         | Yes            | Yes                       | Storage network of Web3 ecosystem.                                                    |


---

## Wireless Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements         | Software Stack               | Open Source | Docker Support | ThreeFold Compatible | Notes                                                                                                                                                                                                                              |
|--------------------|--------------------------------|-------------------------------|------------------------------|-------------|----------------|---------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| [Helium](./depin_specs/wireless_networks/helium.md)         | Decentralized            | CPU, RAM, Storage             | LoRaWAN Network Servers      | Yes         | Yes            | Yes                       | Wireless apps, from long-range sensor tech to cellular connectivity.|
| [Pollum](./depin_specs/wireless_networks/pollum.md)         | Decentralized            | RAM, Processor speed, Storage | Windows or Linux             | Yes         | Partially      | Yes                       | Tailor-made solutions in Web3, AI, and beyond.                                                                                                |
| [Nodle](./depin_specs/wireless_networks/nodle.md)          | Decentralized            | Internet-of-Things            | Nodle                        | Yes         | Yes            | Yes                       | Using smartphones as edge nodes to connect to the physical world.                                                                                                                                                      |
| [World Mobile](./depin_specs/wireless_networks/world_mobile.md)   | Decentralized            | AirNode, Flexibility          | Cardano, Custom blockchain   | No          | Partially      | Yes                       | Decentralised, blockchain-powered mobile network .                                                                                                   |
| [Althea](./depin_specs/wireless_networks/althea.md)         | Decentralized            | Routers, IoT devices          | Ethereum, Custom blockchain  | Yes         | Yes            | Yes                       | Hybrid EVM blockchain purpose-built for infrastructure and connectivity.                                                                                                                       |


---

## Energy Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [Power Ledger](./depin_specs/energy_networks/power_ledger.md)   | Hybrid | No Specific HW | Blockchain | Partially | Yes | Yes | Integrating renewable energy into the grid. |
| [Energy Web](./depin_specs/energy_networks/energy_web.md)     | Hybrid | CPU, RAM, SSD, DSL Connection | OpenEthereum client | Yes | Yes | Yes | Aim to transition to a customer-centric electricity system. |
| [Grid+](./depin_specs/energy_networks/grid_plus.md)          | Hybrid | The Lattice1 device, One SafeCard, Power supply, LAN cable | Lattice Software | Partially | No | Yes | Secure and user-friendly cryptocurrency management wallet. |
| [SunContract](./depin_specs/energy_networks/suncontract.md)    | Decentralized | RAM | Blockchain | Yes | No | Yes | Decentralization of power distribution. |

## Sensor Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [IoTeX](./depin_specs/sensor_networks/iotex.md)          | Decentralized            | Raspberry Pi, ESP32, and Arduino      | Blockchain, Pebble Software  | Yes         | Yes            | Yes                       | Open modular infrastructure for all DePINs.              |
| [Hivemapper](./depin_specs/sensor_networks/hivemapper.md)     | Decentralized            | Hivemapper Dashcam          | ODC API Software                 | Yes     | Yes             | Yes                       | Mapping network for everyone.|
| [WeatherXM](./depin_specs/sensor_networks/weatherxm.md)      | Decentralized            | Modem, Tools, Weather station               | Ethereum, Custom blockchain  | Yes         | No             | Yes                       | Accurate weather services to Web3 enterprises.                               |
| [DIMO](./depin_specs/sensor_networks/dimo.md)           | Decentralized            | IoT devices, vehicles          | DINO Mobile, API-driven platform              | Yes         | No           | No                       | Collect, use, and monetize data from vehicles.                     |
---

## Mobility Networks

| Project Name       | Infrastructure Ownership | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Compatible | Notes                                                                           |
|--------------------|-------------------------|-------------------------------|------------------------------|-------------|----------------|---------------------------|---------------------------------------------------------------------------------|
| [Carv](./depin_specs/mobility_networks/carv.md)           | Decentralized            | CPU, RAM , Internet service    | Ethereum                    | Yes         | Yes            | Yes                       | Fusion of Artificial General Intelligence (AGI) and blockchain. |
| [Drife](./depin_specs/mobility_networks/drife.md)          | Decentralized            | No Particular Hardware         | Blockchain                  | Yes         | No             | Yes                       | Decentralized ride-hailing platform.                                            |
| [Arcade City](./depin_specs/mobility_networks/arcade_city.md)    | Decentralized            | No Particular Hardware         | Blockchain                  | Yes         | No             | Yes                       | Unstoppable peer-to-peer commerce.                               |

---

## Miscellaneous DePIN Projects

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [Livepeer](./depin_specs/miscellaneous_depin_projects/livepeer.md)       | Decentralized                  | GPU, CPU, RAM, Disk           | go-livepeer                  | Yes         | Yes            | Yes                       | Integrate AI video capabilities into the Livepeer network. |
| [Theta Network](./depin_specs/miscellaneous_depin_projects/theta_network.md)  | Hybrid                         | CP, RAM, HDD, Nvidia GPU      | CUDA                         | Yes         | Yes            | Yes                       | Cloud for AI, media and entertainment. |
| [Audius](./depin_specs/miscellaneous_depin_projects/audius.md)         | Decentralized                  | CPU, RAM, SSD, Firewall      | Ethereum, IPFS               | Partially   | Yes            | Yes                       | Digital streaming service that connects fans to artists directly. |
| [Arbol](./depin_specs/miscellaneous_depin_projects/arbol.md)          | Decentralized                  | IoT devices, weather stations  | Blockchain                   | Partially   | No             | Yes                       | Provide climate risk coverage and financial resilience solutions. |
| [Silent Notary](./depin_specs/miscellaneous_depin_projects/silent_notary.md)  | Decentralized                  | Computer, internet, webcam    | Ethereum, Custom blockchain  | Yes         | Yes            | Yes                       | Web 3.0 legal-tech solution for data. |
| [Morpheus](./depin_specs/miscellaneous_depin_projects/morpheus.md) | Hybrid                         | RAM, Storage, CPU             | Custom blockchain, Privacy protocols | Partially   | Yes            | Yes                       | Optimize and automate global supply chains. |

---

## Emerging DePIN Projects

| Project Name       | Infrastructure Ownership | Hardware Requirements                                                           | Software Stack                         | Open Source | Docker Support | ThreeFold Compatible | Notes                                                                                                                                                                                                                                                        |
|--------------------|-------------------------|-------------------------------------------------------------------------------|---------------------------------------|-------------|----------------|---------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| [Aethir](./depin_specs/emerging_depin_projects/aethir.md)         | Decentralized           | GPU                                                                             | Checker Node Client                    | Partial     | Yes            | Yes                       | Distributed cloud compute infrastructure. |
| [Meson Network](./depin_specs/emerging_depin_projects/meson_network.md)  | Decentralized           | Standard server with decent storage                                             | Blackchain                             | Yes         | Yes            | Yes                       | Streamlined bandwidth marketplace.                                                                                      |
| [KYVE](./depin_specs/emerging_depin_projects/kyve.md)           | Decentralized           | CPU, RAM, Disk, OS Mac, Linux-x64 & Linux-arm64 | Cosmos Hub                             | Yes         | No             | Yes                       | Tooling for decentralized data validation, immutability, and retrieval.                                                                           |
| [Spheron Network](./depin_specs/emerging_depin_projects/spheron_network.md)| Decentralized           | CPU, RAM,Storage, NVIDIA GPUs                                                   | MacOS and Linux                        | Partial     | Yes            | Yes                       | Connect GPU resources to a decentralized network.                                                                                                                                             |
| [Wicrypt](./depin_specs/emerging_depin_projects/wicrypt.md)        | Decentralized           | Hotspot Hub                                                                     | Linux Embedded Distribution Environment | No          | No             | Yes                       | Hotspot sharing and token mining network.                                                                                                             |
| [ThreeFold](./depin_specs/emerging_depin_projects/threefold.md)     | Decentralized           | Standard Server                                                                 | ZOS                                    | Yes         | Yes            | Yes                       | Decentralized cloud infrastructure for storage, compute, and network.                                                                                                                                                                                        |

---

## Experimental and Niche DePIN Projects

| Project Name       | Infrastructure Ownership | Hardware Requirements                                                                                          | Software Stack                    | Open Source | Docker Support | ThreeFold Compatible | Notes                                                                                                                                                                                                         |
|--------------------|-------------------------|---------------------------------------------------------------------------------------------------------------|----------------------------------|-------------|----------------|---------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| [SpaceChain](./depin_specs/experimental_and_niche_depin_projects/spacechain.md)     | Decentralized            | 2nd gen flight-tested ZYNQ board, programmable hardware board | Linux and SPC OS, Blockchain      | Yes         | No             | No                        | Decentralized satellite network.                                                                                                                                                   |
| [SmartMesh](./depin_specs/experimental_and_niche_depin_projects/smartmesh.md)      | Decentralized            | ARM Cortex-M series processor, RAM, radio transceiver                                                          | ESP software, Fuse Table software | Yes          | No             | Yes                       | Protocol of the Internet of Things.                                                                                                                                |
| [Elastos](./depin_specs/experimental_and_niche_depin_projects/elastos.md)        | Decentralized            | CPU, RAM, Storage                                                                                              | Blockchain                        | Yes         | No             | Yes                       | Platform that allows users to build and deploy dApps.                                                                                                                          |
| [Autonomys](./depin_specs/experimental_and_niche_depin_projects/autonomys.md)       | Decentralized            | CPU, RAM, Storage                                                                                              | Ubuntu, Mac, Windows, Linux       | Yes         | Yes            | Yes                       | Provide the infrastructure to scale decentralized AI 3.0 applications and more. |