---
title: io.net
description: Detailed information about io.net
sidebar_position: 7
---

# io.net  

## Overview  

io.net is a decentralized AI computing network built on Solana, designed to aggregate underutilized GPU resources globally to power AI and machine learning applications. By leveraging a Decentralized Physical Infrastructure Network (DePIN), io.net connects independent data centers, crypto miners, and projects like Filecoin and Render to provide scalable, cost-effective computing power. Founded by Ahmad Shadid (later succeeded by Tory Green in 2024), the platform aims to democratize access to GPU resources, reducing costs by up to 90% compared to traditional cloud services.  



## Key Features  
- **Currency:** $IO (native token) and $IOSD (USD-pegged stablecoin).  
- **Buying Currency:** Available on exchanges like Binance, where it was listed via a Launchpool campaign in June 2024.  
- **Utility:**  
  - **Payments:** $IO is used to pay for GPU/CPU rentals and transaction fees; $IOSD offers stable pricing.  
  - **Staking:** Stake $IO to secure the network, earn block rewards, and participate in governance.  
  - **Governance:** $IO holders vote on protocol upgrades and ecosystem decisions.  
- **Automation:**  
  - AI-driven dynamic resource allocation optimizes task distribution based on hardware specs, location, and cost.  
  - Smart contracts automate payments, slashing penalties, and reward distribution.  
- **API:** Yes. Integrates with Ray and Kubernetes for scalable AI/ML workflows.  
- **User Perspective:**  
  - **Developers:** Deploy AI models, access 1M+ GPUs, and use tools like IO Cloud for cluster management.  
  - **Providers:** Monetize idle GPUs/CPUs through hourly rewards and staking.  

## How It Works  
1. **Resource Aggregation:**  
   - GPU/CPU providers register devices on io.net, which are verified and pooled into a global network.  
2. **Task Allocation:**  
   - Users submit compute jobs (e.g., AI training), and the platform dynamically assigns tasks to optimal hardware using smart scheduling algorithms.  
3. **Execution & Payment:**  
   - Jobs run on distributed nodes, with results validated via test cases. Payments in $IO/$IOSD are automated via blockchain.  

## Staking  
- **Staking Requirements:**  
  - Minimum stake per GPU: 200 $IO. High-end GPUs (e.g., NVIDIA H100) require 10x multiplier (16,000 $IO for 8 H100s).  
  - 14-day cooldown period for unstaking.  
- **Rewards:**  
  - **Block Rewards:** Distributed hourly—80% to GPU providers, 20% to CPU providers.  
  - **Slashing:** Malicious actors lose staked $IO; slashed tokens are burned after a 1-month appeal window.  

## Documentation  
For technical guides, tokenomics, and API integration:  
- [io.net Docs](https://docs.io.net/)  
- [Staking Guide](https://docs.io.net/docs/staking)  
- [Rewards & Wallets](https://docs.io.net/docs/rewards-wallets)  



## Additional Resources  
- **Official Links:**  
  - [Website](https://io.net) | [GitHub](https://github.com/ionet-official) | [Twitter](https://x.com/ionet)  
- **Community:**  
  - [Telegram](https://t.me/io_net) | [Discord](https://discord.gg/ionet)  
- **Partnerships:**  
  - Collaborations with Aptos Labs, Aethir, and Mind Network enhance AI security and cross-chain interoperability.  



## Ecosystem Components  
| Product       | Functionality                                                                 |  
| - |-|  
| **IO Cloud**  | Manages decentralized GPU clusters for AI/ML deployments. |  
| **IO Worker** | Dashboard for providers to monitor hardware performance and earnings. |  
| **IO Explorer** | Analytics tool tracking network activity, rewards, and resource utilization. |  



## Tokenomics  
- **Max Supply:** 800M.  
- **Distribution:**  
  - 50% to community, 20% to investors, 20% to core contributors, 10% ecosystem fund.  

## FAQ

1. **Is it usable by the average DePIN user?**  
   Yes, io.net is designed to be user-friendly, with an intuitive interface and accessible documentation. It caters to both technical and non-technical users, making it an excellent choice for the average DePIN user.

2. **Can I pay with tokens to use the DePIN product offered by the project?**  
   Yes, io.net supports payment using its native token. Users can also utilize other common tokens such as ETH or USDT, enhancing flexibility.

3. **Can tokens be automatically switched from other standard tokens (e.g. ETH, BTC)?**
   While io.net does not support automatic token switching natively, users can easily convert tokens like ETH or BTC to the native token through major exchanges, ensuring seamless integration.

4. **If I would provide the service, what is my ROI, do we need to stake, etc.?**  
   Providers can earn a competitive ROI by contributing resources. Staking the native token is typically required to participate, with rewards distributed based on contribution levels and market demand.

5. **Why does the project exist, why do the people and the planet need it?**  
   io.net aims to decentralize essential services, enhancing efficiency and sustainability. By optimizing resource utilization, it offers a greener alternative to traditional centralized solutions.

6. **Is it geo-aware?**  
   io.net supports global deployment, allowing users to leverage resources across different regions, ensuring flexibility and compliance with local regulations.

7. **Is it cost-effective?**  
   io.net is highly cost-effective, offering solutions that can be significantly cheaper than centralized alternatives, providing substantial savings.
