---
title: Elastos
description: Detailed information about Elastos
sidebar_position: 4
---

# Elastos  

## Overview  

Elastos is a decentralized SmartWeb ecosystem built on blockchain technology, designed to provide a secure, scalable, and user-centric internet infrastructure. By integrating blockchain, decentralized identity (DID), peer-to-peer networking, and decentralized storage, Elastos aims to redefine how the internet operates, empowering users to own and control their data. The platform focuses on enabling decentralized applications (DApps) and services while maintaining privacy, security, and interoperability.  

## Key Features  
- **Currency:** $ELA (native token).  
- **Buying Currency:** $ELA is available on major exchanges like Coinbase, KuCoin, and Gate.io.  
- **Utility:**  
  - **Payments:** $ELA is used for transactions, staking, and accessing services within the Elastos ecosystem.  
  - **Staking:** Stake $ELA to secure the network, earn rewards, and participate in governance.  
  - **Governance:** $ELA holders can vote on protocol upgrades and ecosystem decisions.  
- **Automation:**  
  - Smart contracts automate transactions, staking rewards, and dispute resolution.  
  - The BeL2 protocol enables trustless, decentralized financial infrastructure for Bitcoin DeFi.  
- **API:** Yes. Elastos supports EVM-compatible smart contracts and integrates with Bitcoin via Zero-Knowledge Proofs (ZKPs).  
- **User Perspective:**  
  - **Developers:** Build DApps on a secure, scalable, and interoperable platform.  
  - **Users:** Access decentralized services while maintaining full control over personal data and digital assets.  

## How It Works  
1. **Resource Aggregation:**  
   - Elastos combines blockchain, DID, and decentralized storage to create a unified SmartWeb infrastructure.  
2. **Task Allocation:**  
   - DApps and services are deployed on the Elastos SmartWeb, leveraging its decentralized components for enhanced security and efficiency.  
3. **Execution & Payment:**  
   - Transactions and smart contract executions are validated via blockchain, with payments in $ELA automated through smart contracts.  

## Staking  
- **Staking Requirements:**  
  - Users and arbiters must stake $ELA to participate in the network, with the amount influencing their reputation and governance power.  
  - No minimum stake for users accessing DApps.  
- **Rewards:**  
  - **Block Rewards:** Distributed to stakers based on their contribution to network security.  
  - **Arbiter Rewards:** Arbiters earn $ELA and BTC rewards for managing time-sensitive transactions and resolving disputes.  

## Documentation  
For detailed documentation, visit [Elastos Docs](https://www.elastos.org/downloads/elastos_whitepaper_en.pdf).  

## Additional Resources  
- [Official Website](https://elastos.org)  
- [Community Link](https://x.com/ElastosInfo)  
- [GitHub Repository](https://github.com/elastos)  

## Ecosystem Components  
| Product       | Functionality                                                                 |  
| - |-|  
| **BeL2 Protocol**  | A Bitcoin Layer 2 solution enabling decentralized financial infrastructure and cross-chain interoperability. |  
| **Elastos DID** | Decentralized identity system for secure and private user authentication. |  
| **Elastos Hive** | Decentralized storage solution for DApps and user data. |  

## Tokenomics  
- **Total Supply:** 25.82M.  
- **Max Supply:** 28.21M.  
- **Distribution:**  
  - 60% allocated as network rewards, 20% to investors, 10% to the team, and 10% to the ecosystem fund.  

## FAQ  

1. **Is it usable by the average DePIN user?**  
   Yes, Elastos is designed to be user-friendly, with tools like Elastos DID and Hive simplifying decentralized identity and storage management. It caters to both technical and non-technical users, making it accessible for the average DePIN user.  

2. **Can I pay with tokens to use the DePIN product offered by the project?**  
   Yes, $ELA is the primary currency for accessing services and DApps within the Elastos ecosystem. Users can also pay with BTC through the BeL2 protocol.  

3. **Can tokens be automatically switched from other standard tokens (e.g. ETH, BTC)?**  
   While $ELA is the native token, users can trade it on major exchanges like Coinbase and KuCoin. Automatic token switching (e.g., BTC to ELA) is not natively supported but can be done through external exchanges.  

4. **If I would provide the service, what is my ROI, do we need to stake, etc.?**  
   Providers can earn passive income by staking $ELA and participating in the network as arbiters. Staking is required for arbiters, and rewards are distributed based on transaction handling and dispute resolution. ROI depends on network activity and staking amount.  

5. **Why does the project exist, why do the people and the planet need it?**  
   Elastos exists to create a decentralized internet where users own and control their data. It promotes privacy, security, and sustainability by reducing reliance on centralized systems and enabling a more equitable digital economy.  

6. **Is it geo-aware?**  
   Elastos does not explicitly mention geo-fencing, but its decentralized nature allows users to deploy resources globally, ensuring flexibility and compliance with local regulations.  

7. **Is it cost-effective?**  
   Elastos is highly cost-effective, offering decentralized services at competitive rates. The BeL2 protocol further enhances efficiency by enabling Bitcoin DeFi without third-party custodians.